{% load url from future %}
{% load i18n %}

<form action="" method="post">
    {% csrf_token %}
    <table>
        {% for form in forms %}
            {{ form.as_table }}
        {% endfor %}
        <tr class="form_buttons">
            <td />
            <td>
                <input type="submit" value="{% trans "Submit" %}" />
            </td>
        </tr>
    </table>
</form>
