{% load ksp_login %}

<script type="text/javascript">var STATIC_URL = "{{ STATIC_URL }}";</script>
<script type="text/javascript" src="https://ajax.googleapis.com/ajax/libs/jquery/1.8.2/jquery.min.js"></script>
<script type="text/javascript" src="{{ STATIC_URL }}ksp_login/js/jquery.simplemodal.1.4.4.min.js"></script>
<script type="text/javascript" src="{{ STATIC_URL }}ksp_login/js/jquery.init.js"></script>
<script type="text/javascript" src="{{ STATIC_URL }}ksp_login/js/backend_list.js"></script>
{% if not user.is_authenticated %}
  <div id="ksp_login_modal_box" style="display: none;">
    {% ksp_login_auth_form as auth_form %}
    {% include "ksp_login/parts/login_full_contents.html" with form=auth_form %}
  </div>
{% endif %}
