.ksp_login_provider_list form {
    display: none;
}

.ksp_login_provider_list {
    list-style: none;
}

.ksp_login_provider_list > li {
    display: inline;
}

.ksp_login_provider_list img {
    cursor: pointer;
    padding: 5px;
    vertical-align: middle;
}

div.ksp_login_selected_input_provider{
    text-align: center;
}

img.ksp_login_selected_provider_button {
    background: #ccccff;
}

.simplemodal-overlay {
    background-color: #000;
}

.simplemodal-container {
    background-color: #fff;
    padding: 2em;
}

#ksp_login_modal_box {
    overflow: hidden;
    min-width: 22em;
    max-width: 40em;
}

.simplemodal-container a.modalCloseImg {
    background: url('../img/close.svg');
    background-size: 100% 100%;
    height: 2em;
    width: 2em;
    position: absolute;
    right: -1em;
    top: -1em;
    z-index: 4700;
}
